hstrat.hstrat.stratum\_retention\_predicates.StratumRetentionPredicateRecencyProportionalResolution
===================================================================================================

.. currentmodule:: hstrat.hstrat.stratum_retention_predicates

.. autoclass:: StratumRetentionPredicateRecencyProportionalResolution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StratumRetentionPredicateRecencyProportionalResolution.CalcMrcaUncertaintyUpperBound
      ~StratumRetentionPredicateRecencyProportionalResolution.CalcNumStrataRetainedExact
      ~StratumRetentionPredicateRecencyProportionalResolution.CalcNumStrataRetainedUpperBound
      ~StratumRetentionPredicateRecencyProportionalResolution.CalcRankAtColumnIndex
      ~StratumRetentionPredicateRecencyProportionalResolution.__init__
   
   

   
   
   